@@ -65,6 +65,7 @@ OC.L10N.register(
     "before" : "abans",
     "start" : "comença",
     "end" : "final",
+    "Editing reminders of unknown type not supported." : "L'edició de recordatoris de tipus desconegut no està suportada.",
     "Week {number} of {year}" : "Setmana {number} de {year}",
     "Successfully imported" : "S'ha importat correctament",
     "Partially imported, 1 failure" : "Parcialment importat, 1 error",
@@ -80,6 +81,7 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} al final de l'esdeveniment",
     "{type} at {time}" : "{type} a {time}",
     "{calendar} shared by {owner}" : "{calendar} compartit per {owner}",
+    "Please enter a valid WebCal-URL" : "Introdueix una WebCal-URL vàlida si us plau",
     "Title of the Event" : "Títol de l'esdeveniment",
     "starts" : "comença",
     "ends" : "finalitza",
@@ -93,15 +95,19 @@ OC.L10N.register(
     "Location" : "Ubicació",
     "Description" : "Descripció",
     "Event status" : "Estat de l'esdeveniment",
+    "Visibility when sharing" : "Visibilitat en compartir",
     "Export" : "Exporta",
+    "%s has published the calendar %s" : "%s ha publicat el calendari %s",
     "Hello," : "Hola,",
     "Click here to access it" : "Click aquí per accedir",
     "Cheers!" : "Salut!",
+    "Click on the link below to access it" : "Entra a l'enllaç de sota per accedir-hi",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A causa d'un error (bug) de \"upstrem\", el calendari no suporta la funció \"asset pipeline\"",
     "Day" : "Dia",
     "Week" : "Setmana",
     "Month" : "Mes",
     "Today" : "Avui",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Alguns esdeveniments d'aquest calendari contenen errors. Revisa la consola JS per a més informació.",
     "Share Calendar" : "Comparteix el calendari",
     "Shared" : "Compartit",
     "More" : "Més",
@@ -142,6 +148,11 @@ OC.L10N.register(
     "Analyzing calendar" : "Analitzant calendari",
     "New calendar" : "Calendari nou",
     "File is empty" : "El Fitxer està plè",
+    "Import scheduled" : "Importa els programats",
+    "Publish URL" : "Publica la URL",
+    "Settings & import" : "Configuració & importació",
+    "Skip simple event editor" : "Salta l'editor simple d'esdeveniments",
+    "Show week numbers" : "Mostra el número de la setmana",
     "Import calendar" : "Importa calendari",
     "No Calendars selected for import" : "No heu sel·leccionat cap calendari per a importar ",
     "Primary CalDAV address" : "Adreça primària de caldav",
