@@ -2,6 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalender",
+    "%s has published the calendar \"%s\"" : "%s har offentliggjort kalenderen \"%s\"",
+    "Too many redirects. Aborting ..." : "For mange omdirigeringer. Afbryder ...",
+    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Serveren gav os ikke adgang til kalenderen (HTTP {%s} fejl)",
+    "Error connecting to remote server" : "Fejl ved forbindelse til serveren",
+    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fejl efter anmodning fra serveren. Dette er muligvis relateret til ikke ens certifikater",
+    "Error requesting resource on remote server" : "Fejl efter anmodning fra server",
     "Individual" : "Individuelt",
     "Group" : "Gruppe",
     "Resource" : "Ressource",
@@ -10,11 +16,17 @@ OC.L10N.register(
     "Required" : "Krævet",
     "Optional" : "Valgfri",
     "Does not attend" : "Deltager ikke",
+    "{name} ({email})" : "{name} ({email})",
     "You are in an unknown timezone ({tz}), falling back to UTC" : "Du er i en ukendt tidszone ({tz}), -sætter tiden til UTC",
     "Please create a calendar first." : "Opret venligst en kalender først",
     "New event" : "Opret begivenhed",
+    "CalDAV address for clients" : "CalDAV addresse for klienter",
     "Error saving WebCal-calendar" : "Kunne ikke gemme WebCal-kalender",
+    "WebDAV address for subscriptions" : "WeblDAV addresse for abonnementer",
+    "EMail has been sent." : "Email afsendt",
+    "There was an issue while sending your EMail." : "Der var et problem ved afsendelse af din Email.",
     "group" : "gruppe",
+    "Details" : "Detaljer",
     "Attendees" : "Deltagere",
     "Reminders" : "Påmindindelser",
     "Repeating" : "Gentagende",
@@ -34,6 +46,7 @@ OC.L10N.register(
     "Every year" : "Hvert år",
     "never" : "aldrig",
     "after" : "efter",
+    "How about getting started by importing some calendars?" : "Hvad med at starte med at importere nogle kalendere?",
     "At time of event" : "På tidspunktet for begivenheden",
     "5 minutes before" : "5 minutter før",
     "10 minutes before" : "10 minutter før",
@@ -70,6 +83,7 @@ OC.L10N.register(
     "{type} at {time}" : "{type} på {time}",
     "{calendar} shared by {owner}" : "{calendar} delt af {owner}",
     "Please enter a valid WebCal-URL" : "Angiv en gyldig WebCal-URL",
+    "Severe error in webcal proxy. Please contact administrator for more information." : "Alvorlig fejl i webcal proxy. Kontakt venligst administratoren for mere information.",
     "Title of the Event" : "Titel på begivenheden",
     "starts" : "starter",
     "ends" : "slutter",
@@ -85,6 +99,13 @@ OC.L10N.register(
     "Event status" : "Begivenhedens status",
     "Visibility when sharing" : "Synlighed ved deling",
     "Export" : "Eksportér",
+    "%s has published the calendar %s" : "%s har offentliggjort kalenderen %s",
+    "Hello," : "Hej,",
+    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Vi ønskede at informere dig om at %s har offentliggjort kalenderen {boldstart}%s{boldend}.",
+    "Click here to access it" : "Klik her for at få adgang til den",
+    "Cheers!" : "Hav en fortsat god dag.",
+    "We wanted to inform you that %s has published the calendar %s." : "Vi ønskede at informere dig om at %s har offentliggjort kalenderen %s.",
+    "Click on the link below to access it" : "Klik på linket under for at få adgang til den",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "På grund af en \"upstream bug\", er kalenderen, i øjeblikket, ikke i stand til at understøtte funktionen \"asset pipeline\".",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Kontakt venligst din administrator og bed om at \"asset-pipeline.enabled\" bliver slået fra.",
     "Day" : "Dag",
@@ -97,12 +118,19 @@ OC.L10N.register(
     "More" : "Mere",
     "Edit" : "Redigér",
     "Link" : "Link",
+    "iCal link" : "iCal link",
     "Download" : "Hent",
     "Share with users or groups" : "Del med brugere eller grupper",
     "can edit" : "kan redigere",
+    "Share link" : "Del link",
+    "Public access" : "Offentlig adgang",
+    "Email link to person" : "E-mail link til person",
+    "Send" : "Send",
     "New Calendar" : "Ny kalender",
     "Name" : "Navn",
     "New Subscription" : "Tilføj abonnement",
+    "Go back" : "Gå tilbage",
+    "Go forward" : "Gå frem",
     "Edit event" : "Rediger begivenhed",
     "Delete Event" : "Slet begivenhed",
     "Save Event" : "Gem begivenhed",
@@ -128,7 +156,12 @@ OC.L10N.register(
     "Analyzing calendar" : "Analyserer kalender",
     "The file contains objects incompatible with the selected calendar" : "Filen indeholder objekter som ikke er kompatible med den valgte kalender",
     "New calendar" : "Ny kalender",
+    "File is empty" : "Fil er tom",
     "Import scheduled" : "Importering planlagt",
+    "Subscribe & embed" : "abonner & indlejre",
+    "Publish URL" : "Offentliggør URL",
+    "Iframe to integrate" : "Iframe for at integrere ",
+    "Settings & import" : "Indstillinger & importer",
     "Skip simple event editor" : "Spring over enkel begivenheds tekstbehandler",
     "Show week numbers" : "Vis ugenummer ",
     "Import calendar" : "Importer kalender",
