@@ -2,12 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Calendario",
+    "%s has published the calendar \"%s\"" : "%s ha publicado el calendario \"%s\"",
     "Too many redirects. Aborting ..." : "Demasiadas redirecciones. Cancelando...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "El servidor remoto no dio acceso al calendario (error HTTP {%s})",
     "Error connecting to remote server" : "Error al conectar con el servidor remoto",
     "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Error al solicitar recurso al servidor remoto. Esto puede estar relacionado con un error de certificado",
     "Error requesting resource on remote server" : "Error al pedir recurso en servidor remoto",
-    "%s has published the calendar \"%s\"" : "%s ha publicado el calendario \"%s\"",
     "Individual" : "Individual",
     "Group" : "Grupo",
     "Resource" : "Recurso",
@@ -118,7 +118,7 @@ OC.L10N.register(
     "More" : "Más",
     "Edit" : "Editar",
     "Link" : "Enlace",
-    "WebCal URL" : "WebCal URL",
+    "iCal link" : "enlace iCal",
     "Download" : "Descargar",
     "Share with users or groups" : "Compartir con usuarios o grupos",
     "can edit" : "puede editar",
@@ -129,7 +129,6 @@ OC.L10N.register(
     "New Calendar" : "Nuevo calendario",
     "Name" : "Nombre",
     "New Subscription" : "Nueva suscripción",
-    "WebCal-URL" : "WebCal-URL",
     "Go back" : "Atrás",
     "Go forward" : "Adelante",
     "Edit event" : "Editar evento",
@@ -159,7 +158,7 @@ OC.L10N.register(
     "New calendar" : "Nuevo calendario",
     "File is empty" : "El archivo está vacío",
     "Import scheduled" : "Importar horario",
-    "Settings" : "Ajustes",
+    "Subscribe & embed" : "Suscribir e incrustar",
     "Publish URL" : "Publicar URL",
     "Iframe to integrate" : "Iframe para integrar",
     "Settings & import" : "Ajustes & importar",
