@@ -2,12 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Agenda",
+    "%s has published the calendar \"%s\"" : "%s a publié le calendrier \"%s\"",
     "Too many redirects. Aborting ..." : "Trop de redirections. Annulation en cours...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Ce serveur distant ne semble pas nous donner accès au calendrier (erreur HTTP {%s})",
     "Error connecting to remote server" : "Erreur de connexion au serveur distant",
     "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Erreur lors de la demande de ressources auprès du serveur distant. Cela pourrait être liée à une incompatibilité de certificat",
     "Error requesting resource on remote server" : "Erreur lors de la demande de ressources auprès du serveur distant.",
-    "%s has published the calendar \"%s\"" : "%s a publié le calendrier \"%s\"",
     "Individual" : "Individuel",
     "Group" : "Groupe",
     "Resource" : "Ressource",
@@ -111,14 +111,14 @@ OC.L10N.register(
     "Day" : "Jour",
     "Week" : "Semaine",
     "Month" : "Mois",
-    "Today" : "Auj.",
+    "Today" : "Aujourd'hui",
     "Some events in this calendar are broken. Please check the JS console for more info." : "Certains événements de cet agenda sont cassés. Merci de consulter la console JS pour plus d'info.",
     "Share Calendar" : "Partager l'agenda",
     "Shared" : "Partagé",
     "More" : "Plus",
     "Edit" : "Éditer",
     "Link" : "Lien",
-    "WebCal URL" : "URL WebCal",
+    "iCal link" : "Lien iCal",
     "Download" : "Télécharger",
     "Share with users or groups" : "Partager avec des utilisateurs ou des groupes",
     "can edit" : "peut modifier",
@@ -129,7 +129,6 @@ OC.L10N.register(
     "New Calendar" : "Nouvel agenda",
     "Name" : "Nom",
     "New Subscription" : "Nouvel abonnement",
-    "WebCal-URL" : "URL WebCal",
     "Go back" : "Aller au précédent",
     "Go forward" : "Aller au suivant",
     "Edit event" : "Modifier l'événement",
@@ -159,7 +158,7 @@ OC.L10N.register(
     "New calendar" : "Nouvel agenda",
     "File is empty" : "Le fichier est vide",
     "Import scheduled" : "Importation planifiée",
-    "Settings" : "Paramètres",
+    "Subscribe & embed" : "Abonnement & intégration",
     "Publish URL" : "Publier l'URL",
     "Iframe to integrate" : "Iframe à intégrer",
     "Settings & import" : "Paramètres & Importation",
