@@ -2,6 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Dagatal",
+    "%s has published the calendar \"%s\"" : "%s gaf út dagatalið \"%s\"",
+    "Too many redirects. Aborting ..." : "Of margar endurbeiningar. Hætti við ...",
+    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Fjartengdi þjónninn gaf ekki aðgang að dagatalinu (HTTP {%s} villa)",
+    "Error connecting to remote server" : "Villa við tengingu við fjartengdan þjón",
+    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Villa við beiðni um tilfang á fjartengdum þjóni. Þetta gæti stafað af misræmi í skilríkjum (certificate)",
+    "Error requesting resource on remote server" : "Villa við beiðni um tilfang á fjartengdum þjóni",
     "Individual" : "Einstaklingur",
     "Group" : "Hópur",
     "Resource" : "Tilfang",
@@ -10,16 +16,26 @@ OC.L10N.register(
     "Required" : "þetta þarf",
     "Optional" : "Valkvætt",
     "Does not attend" : "Mætir ekki",
+    "{name} ({email})" : "{name} ({email})",
     "You are in an unknown timezone ({tz}), falling back to UTC" : "Þú ert á óþekktu tímabelti ({tz}), fell aftur á UTC-tíma",
     "Please create a calendar first." : "Búðu fyrst til dagatal.",
     "New event" : "Nýr atburður",
+    "CalDAV address for clients" : "CalDAV-vistfang fyrir biðlara",
+    "Error saving WebCal-calendar" : "Villa við að vista WebCal-dagatal",
+    "WebDAV address for subscriptions" : "WebDAV-vistfang fyrir áskriftir",
+    "EMail has been sent." : "Tölvupósturinn var sendur.",
+    "There was an issue while sending your EMail." : "Það kom upp vandamál við að senda tölvupóstinn þinn.",
     "group" : "hópur",
+    "Details" : "Nánar",
     "Attendees" : "Þáttakendur",
     "Reminders" : "Áminningar",
     "Repeating" : "Endurtekning",
     "When shared show full event" : "Þegar er deilt, birta allan atburð",
     "When shared show only busy" : "Þegar er deilt, birta eingöngu upptekið",
     "When shared hide this event" : "Þegar er deilt, fela þennan atburð",
+    "Confirmed" : "Staðfest",
+    "Tentative" : "Bráðabirgða",
+    "Cancelled" : "Hætt við",
     "Please add a title!" : "Settu inn titil!",
     "Please select a calendar!" : "Veldu dagatal!",
     "Global" : "Almennt",
@@ -30,6 +46,7 @@ OC.L10N.register(
     "Every year" : "Árlega",
     "never" : "aldrei",
     "after" : "eftir",
+    "How about getting started by importing some calendars?" : "Hvernig væri að byrja á því að flytja inn einhver dagatöl?",
     "At time of event" : "Þegar atburður á sér stað",
     "5 minutes before" : "5 mínútum fyrir",
     "10 minutes before" : "10 mínútum fyrir",
@@ -65,6 +82,8 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} við endatíma atburðar",
     "{type} at {time}" : "{type} klukkan {time}",
     "{calendar} shared by {owner}" : "{calendar} deilt af {owner}",
+    "Please enter a valid WebCal-URL" : "Skráðu inn gilda WebCal-slóð",
+    "Severe error in webcal proxy. Please contact administrator for more information." : "Alvarleg villa í webcal-milliþjóni. Hafðu samband við kerfisstjóra.",
     "Title of the Event" : "Titill atburðar",
     "starts" : "byrjar",
     "ends" : "endar",
@@ -77,24 +96,41 @@ OC.L10N.register(
     "Close" : "Loka",
     "Location" : "Staðsetning",
     "Description" : "Lýsing",
+    "Event status" : "Staða atburðar",
+    "Visibility when sharing" : "Sýnileiki við deilingu",
     "Export" : "Flytja út",
+    "%s has published the calendar %s" : "%s gaf út dagatalið %s",
+    "Hello," : "Halló,",
+    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Við vildum láta þig vita að %s gaf út dagatalið {boldstart}%s{boldend}.",
+    "Click here to access it" : "Smelltu hér til að nálgast það",
+    "Cheers!" : "Til hamingju!",
+    "We wanted to inform you that %s has published the calendar %s." : "Við vildum láta þig vita að s gaf út dagatalið %s.",
+    "Click on the link below to access it" : "Smelltu á tengilinn hér fyrir neðan til að nálgast það",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Vegna villu í frumkóða, verður dagatalið ekki nothæft með stuðningi við pípaða vinnslu tilfanga.",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Hafðu samband við kerfisstjóra og biddu þá/hann um að gera \"asset-pipeline.enabled\" stillingakostinn óvirkann.",
     "Day" : "Dagur",
     "Week" : "Vika",
     "Month" : "Mánuður",
     "Today" : "Í dag",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Sumir atburðir í þessu dagatali eru gallaðir. Athugaðu JS-stjórnborðið til að sjá frekari upplýsingar.",
     "Share Calendar" : "Deila dagatali",
     "Shared" : "Deilt",
     "More" : "Meira",
     "Edit" : "Breyta",
     "Link" : "Tengill",
+    "iCal link" : "iCal-tengill",
     "Download" : "Sækja",
     "Share with users or groups" : "Deila með notendum eða hópum",
     "can edit" : "getur breytt",
+    "Share link" : "Deila tengli",
+    "Public access" : "Opinber aðgangur",
+    "Email link to person" : "Senda veftengil í tölvupósti til notanda",
+    "Send" : "Senda",
     "New Calendar" : "Nýtt dagatal",
     "Name" : "Heiti",
     "New Subscription" : "Ný áskrift",
+    "Go back" : "Fara til baka",
+    "Go forward" : "Fara áfram",
     "Edit event" : "Breyta atburði",
     "Delete Event" : "Eyða atburði",
     "Save Event" : "Vista atburð",
@@ -120,8 +156,14 @@ OC.L10N.register(
     "Analyzing calendar" : "Greini dagatal",
     "The file contains objects incompatible with the selected calendar" : "Skráin inniheldur atriði sem ekki eru samhæfanleg völdu dagatali",
     "New calendar" : "Nýtt dagatal",
+    "File is empty" : "Skráin er tóm",
     "Import scheduled" : "Áætlaður innflutningur",
-    "Settings" : "Stillingar",
+    "Subscribe & embed" : "Gerast áskrifandi og ívefja",
+    "Publish URL" : "Gefa út slóð",
+    "Iframe to integrate" : "Iframe-rammi til að samþætta",
+    "Settings & import" : "Stillingar og innflutningur",
+    "Skip simple event editor" : "Sleppa einföldum atburðaritli",
+    "Show week numbers" : "Sýna vikunúmer",
     "Import calendar" : "Flytja inn dagatal",
     "No Calendars selected for import" : "Engin dagatöl valin til innflutnings",
     "Primary CalDAV address" : "Aðal-CalDAV-vistfang",
