@@ -23,8 +23,8 @@ OC.L10N.register(
     "CalDAV address for clients" : "Indirizzo CalDAV per i client",
     "Error saving WebCal-calendar" : "Errore durante il salvataggio del calendario WebCal",
     "WebDAV address for subscriptions" : "Indirizzo WebDAV per le sottoscrizioni",
-    "EMail has been sent." : "L'email è stata inviata.",
-    "There was an issue while sending your EMail." : "C'è stato un problema durante l'invio della tua email.",
+    "EMail has been sent." : "Il messaggio è stata inviato.",
+    "There was an issue while sending your EMail." : "C'è stato un problema durante l'invio del tuo messaggio.",
     "group" : "gruppo",
     "Details" : "Dettagli",
     "Attendees" : "Partecipanti",
