@@ -30,9 +30,9 @@ OC.L10N.register(
     "Attendees" : "Dalyviai",
     "Reminders" : "Priminimai",
     "Repeating" : "Pasikartojimas",
-    "When shared show full event" : "Dalijantis rodyti pilną įvykį",
-    "When shared show only busy" : "Dalijantis rodyti kaip užimtą",
-    "When shared hide this event" : "Dalijantis nerodyti šio įvykio",
+    "When shared show full event" : "Bendrinant, rodyti pilną įvykį",
+    "When shared show only busy" : "Bendrinant rodyti tik užimtą",
+    "When shared hide this event" : "Bendrinant, slėpti šį įvykį",
     "Confirmed" : "Patvirtintas",
     "Cancelled" : "Atsisakyta",
     "Please add a title!" : "Pridėkite pavadinimą!",
