@@ -2,12 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalender",
+    "%s has published the calendar \"%s\"" : "%s publiceerde agenda \"%s\"",
     "Too many redirects. Aborting ..." : "Teveel doorverwijzingen. Afbreken ...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "De externe server verleende geen toegang tot de agenda (HTTP {%s} fout)",
     "Error connecting to remote server" : "Fout bij het verbinden met de externe server",
     "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fout bij opvragen object op externe server. Dit kan te maken hebben met een onjuist certificaat",
     "Error requesting resource on remote server" : "Fout bij opvragen object op externe server.",
-    "%s has published the calendar \"%s\"" : "%s publiceerde agenda \"%s\"",
     "Individual" : "Individueel",
     "Group" : "Groep",
     "Resource" : "Bron",
@@ -118,7 +118,7 @@ OC.L10N.register(
     "More" : "Meer",
     "Edit" : "Bewerk",
     "Link" : "Link",
-    "WebCal URL" : "WebCal URL",
+    "iCal link" : "iCal link",
     "Download" : "Downloaden",
     "Share with users or groups" : "Delen met gebruikers of groepen",
     "can edit" : "kan wijzigen",
@@ -129,7 +129,6 @@ OC.L10N.register(
     "New Calendar" : "Nieuwe agenda",
     "Name" : "Naam",
     "New Subscription" : "Nieuw abonnement",
-    "WebCal-URL" : "WebCal-URL",
     "Go back" : "Ga terug",
     "Go forward" : "Ga verder",
     "Edit event" : "Bewerk gebeurtenis",
@@ -159,7 +158,7 @@ OC.L10N.register(
     "New calendar" : "Nieuwe agenda",
     "File is empty" : "Bestand te leeg",
     "Import scheduled" : "Import ingepland",
-    "Settings" : "Instellingen",
+    "Subscribe & embed" : "Abonneren & inbedden",
     "Publish URL" : "Publiceren URL",
     "Iframe to integrate" : "Iframe om te integreren",
     "Settings & import" : "Instellingen & importeren",
