@@ -2,12 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Календарь",
+    "%s has published the calendar \"%s\"" : "%s опубликовал календарь \"%s\"",
     "Too many redirects. Aborting ..." : "Очень много перенаправлений. Отмена...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Удалённый сервер не предоставил нам доступ к календарю (ошибка HTTP {%s})",
     "Error connecting to remote server" : "Ошибка подключения к удаленному серверу",
     "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Ошибка запроса ресурса на удаленном сервере. Это может  быть связано с несовпадением сертификата.",
     "Error requesting resource on remote server" : "Ошибка запроса ресурса на удалённом сервере",
-    "%s has published the calendar \"%s\"" : "%s опубликовал календарь \"%s\"",
     "Individual" : "Личность",
     "Group" : "Группа",
     "Resource" : "Ресурс",
@@ -118,7 +118,7 @@ OC.L10N.register(
     "More" : "Больше",
     "Edit" : "Редактировать",
     "Link" : "Ссылка",
-    "WebCal URL" : "Адрес WebCal",
+    "iCal link" : "Ссылка iCal",
     "Download" : "Скачать",
     "Share with users or groups" : "Поделиться с пользователями или группами",
     "can edit" : "можно редактировать",
@@ -129,7 +129,6 @@ OC.L10N.register(
     "New Calendar" : "Новый Календарь",
     "Name" : "Название",
     "New Subscription" : "Новая подписка",
-    "WebCal-URL" : "Адрес WebCal",
     "Go back" : "Назад",
     "Go forward" : "Вперед",
     "Edit event" : "Редактировать событие",
@@ -159,12 +158,12 @@ OC.L10N.register(
     "New calendar" : "Новый календарь",
     "File is empty" : "Файл пуст",
     "Import scheduled" : "Импорт запланирован",
-    "Settings" : "Настройки",
+    "Subscribe & embed" : "Подписаться и встроить",
     "Publish URL" : "Опубликовать URL",
     "Iframe to integrate" : "Iframe для встраивания",
     "Settings & import" : "Настройки и импорт",
     "Skip simple event editor" : "Не использовать простой редактор события",
-    "Show week numbers" : "Показать номера недель",
+    "Show week numbers" : "Показывать номера недель",
     "Import calendar" : "Импорт календаря",
     "No Calendars selected for import" : "Не выбраны календари для импорта",
     "Primary CalDAV address" : "Основной адрес синхронизации CalDAV",
