@@ -2,12 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalendar",
+    "%s has published the calendar \"%s\"" : "%s ka publikuar kalendarin \"%s\"",
     "Too many redirects. Aborting ..." : "Shumë ridrejtime. Duke e ndërprerë ...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Serveri i largët nuk na dha akses në kalendar (gabim HTTP {%s})",
     "Error connecting to remote server" : "Gabim gjatë lidhjes me serverin e largët",
     "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Gabim gjatë kërkimit të burimit në serverin e largët. Kjo mund të jetë e lidhur me një mospërputhje të çertifikatave.",
     "Error requesting resource on remote server" : "Gabim gjatë kërkimit të burimit në serverin e largët.",
-    "%s has published the calendar \"%s\"" : "%s ka publikuar kalendarin \"%s\"",
     "Individual" : "Individual",
     "Group" : "Grup",
     "Resource" : "Burim",
@@ -118,7 +118,6 @@ OC.L10N.register(
     "More" : "Më tepër",
     "Edit" : "Përpunoni",
     "Link" : "Lidhje",
-    "WebCal URL" : "URL WebCal",
     "Download" : "Shkarkoje",
     "Share with users or groups" : "Ndajeni me përdorues ose grupe",
     "can edit" : "mund të përpunojnë",
@@ -129,7 +128,6 @@ OC.L10N.register(
     "New Calendar" : "Kalendar i ri",
     "Name" : "Emër",
     "New Subscription" : "Pajtim i Ri",
-    "WebCal-URL" : "WebCal-URL",
     "Go back" : "Shko prapa",
     "Go forward" : "Shko para",
     "Edit event" : "Përpunoni veprimtarinë",
@@ -159,7 +157,6 @@ OC.L10N.register(
     "New calendar" : "Kalendar i ri",
     "File is empty" : "Skedari është bosh",
     "Import scheduled" : "Importimi u planifikua",
-    "Settings" : "Konfigurime",
     "Publish URL" : "Publiko URL",
     "Iframe to integrate" : "Iframe për tu integruar",
     "Settings & import" : "Konfigurimet dhe importi",
