@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Calendar" : "Takvim",
     "%s has published the calendar \"%s\"" : "%s, \"%s\" takvimini yayınladı",
+    "Too many redirects. Aborting ..." : "Çok fazla yönlendirme yapıldı. Vazgeçiliyor ...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Uzak sunucu takvim erişimine izin vermedi (HTTP {%s} hatası)",
     "Error connecting to remote server" : "Uzak sunucuya bağlanılırken bir sorun çıktı",
     "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Uzak sunucu üzerindeki kaynak istenirken bir sorun çıktı. Bu sorun bir sertifika uyuşmazlığından kaynaklanıyor olabilir",
@@ -117,7 +118,7 @@ OC.L10N.register(
     "More" : "Diğer",
     "Edit" : "Düzenle",
     "Link" : "Bağlantı",
-    "iCal link" : "iCal bağlantı",
+    "iCal link" : "iCal bağlantısı",
     "Download" : "İndir",
     "Share with users or groups" : "Kullanıcı ve gruplarla paylaş",
     "can edit" : "düzenleyebilir",
@@ -157,7 +158,7 @@ OC.L10N.register(
     "New calendar" : "Takvim ekle",
     "File is empty" : "Dosya boş",
     "Import scheduled" : "Alma işlemi zamanlandı",
-    "Subscribe & embed" : "Abone ol ve yerleştir",
+    "Subscribe & embed" : "Abone ol ve göm",
     "Publish URL" : "Yayın adresi",
     "Iframe to integrate" : "bütünleştirilecek Iframe",
     "Settings & import" : "Ayarlar ve Alma",
