@@ -2,12 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "日历",
+    "%s has published the calendar \"%s\"" : "%s 发布了 \"%s\" 日历",
     "Too many redirects. Aborting ..." : "太多重定向。取消中...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "远程服务器日程无法访问 (HTTP {%s} 错误)",
     "Error connecting to remote server" : "连接远程服务器出错",
     "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "获取远程服务器资源出错。可能由于未通过鉴定导致。",
     "Error requesting resource on remote server" : " 获取远程服务器资源出错",
-    "%s has published the calendar \"%s\"" : "%s 发布了 \"%s\" 日历",
     "Individual" : "个人",
     "Group" : "群组",
     "Resource" : "源",
@@ -118,7 +118,7 @@ OC.L10N.register(
     "More" : "更多",
     "Edit" : "编辑",
     "Link" : "链接",
-    "WebCal URL" : "WebCal地址",
+    "iCal link" : "iCal 链接",
     "Download" : "下载",
     "Share with users or groups" : "共享给其他组或者用户",
     "can edit" : "可编辑",
@@ -129,7 +129,6 @@ OC.L10N.register(
     "New Calendar" : "新建日历",
     "Name" : "名称",
     "New Subscription" : "新的订阅",
-    "WebCal-URL" : "WebCal地址",
     "Go back" : "回到上一步",
     "Go forward" : "向前",
     "Edit event" : "编辑事件",
@@ -159,7 +158,7 @@ OC.L10N.register(
     "New calendar" : "新建日历",
     "File is empty" : "文件是空的",
     "Import scheduled" : "导入时间表",
-    "Settings" : "设置",
+    "Subscribe & embed" : "订阅 & 嵌入",
     "Publish URL" : "发布 URL",
     "Iframe to integrate" : "使用Iframe框架嵌入",
     "Settings & import" : "设置 & 导入",
